==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/redis/v20180412/models/DescribeInstanceSecurityGroupResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.redis.v20180412.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeInstanceSecurityGroupResponse extends AbstractModel{

    /**
    * 实例安全组信息
    */
    @SerializedName("InstanceSecurityGroupsDetail")
    @Expose
    private InstanceSecurityGroupDetail [] InstanceSecurityGroupsDetail;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 实例安全组信息 
     * @return InstanceSecurityGroupsDetail 实例安全组信息
     */
    public InstanceSecurityGroupDetail [] getInstanceSecurityGroupsDetail() {
        return this.InstanceSecurityGroupsDetail;
    }

    /**
     * Set 实例安全组信息
     * @param InstanceSecurityGroupsDetail 实例安全组信息
     */
    public void setInstanceSecurityGroupsDetail(InstanceSecurityGroupDetail [] InstanceSecurityGroupsDetail) {
        this.InstanceSecurityGroupsDetail = InstanceSecurityGroupsDetail;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeInstanceSecurityGroupResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeInstanceSecurityGroupResponse(DescribeInstanceSecurityGroupResponse source) {
        if (source.InstanceSecurityGroupsDetail != null) {
            this.InstanceSecurityGroupsDetail = new InstanceSecurityGroupDetail[source.InstanceSecurityGroupsDetail.length];
            for (int i = 0; i < source.InstanceSecurityGroupsDetail.length; i++) {
                this.InstanceSecurityGroupsDetail[i] = new InstanceSecurityGroupDetail(source.InstanceSecurityGroupsDetail[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "InstanceSecurityGroupsDetail.", this.InstanceSecurityGroupsDetail);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.874-sources.jar: com/tencentcloudapi/redis/v20180412/models/DescribeInstanceSecurityGroupResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.redis.v20180412.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeInstanceSecurityGroupResponse extends AbstractModel{

    /**
    * 实例安全组信息。
    */
    @SerializedName("InstanceSecurityGroupsDetail")
    @Expose
    private InstanceSecurityGroupDetail [] InstanceSecurityGroupsDetail;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 实例安全组信息。 
     * @return InstanceSecurityGroupsDetail 实例安全组信息。
     */
    public InstanceSecurityGroupDetail [] getInstanceSecurityGroupsDetail() {
        return this.InstanceSecurityGroupsDetail;
    }

    /**
     * Set 实例安全组信息。
     * @param InstanceSecurityGroupsDetail 实例安全组信息。
     */
    public void setInstanceSecurityGroupsDetail(InstanceSecurityGroupDetail [] InstanceSecurityGroupsDetail) {
        this.InstanceSecurityGroupsDetail = InstanceSecurityGroupsDetail;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeInstanceSecurityGroupResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeInstanceSecurityGroupResponse(DescribeInstanceSecurityGroupResponse source) {
        if (source.InstanceSecurityGroupsDetail != null) {
            this.InstanceSecurityGroupsDetail = new InstanceSecurityGroupDetail[source.InstanceSecurityGroupsDetail.length];
            for (int i = 0; i < source.InstanceSecurityGroupsDetail.length; i++) {
                this.InstanceSecurityGroupsDetail[i] = new InstanceSecurityGroupDetail(source.InstanceSecurityGroupsDetail[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "InstanceSecurityGroupsDetail.", this.InstanceSecurityGroupsDetail);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
